barrierBlur property
The blur intensity of the barrier overlay shown behind the nav bar.
Set to 0 and barrierColor to Colors.transparent to disable the barrier.
Defaults to 4.0.
Implementation
final double barrierBlur;
The blur intensity of the barrier overlay shown behind the nav bar.
Set to 0 and barrierColor to Colors.transparent to disable the barrier.
Defaults to 4.0.
final double barrierBlur;