onMenuToggle property
Called when the menu opens or closes.
The bool parameter is true when the menu opens and false when it closes.
Implementation
final ValueChanged<bool>? onMenuToggle;
Called when the menu opens or closes.
The bool parameter is true when the menu opens and false when it closes.
final ValueChanged<bool>? onMenuToggle;