selectedDisplayMode property
Display mode when the menu tab is selected (menu is open).
Implementation
final FloaticaTabDisplayMode selectedDisplayMode;
Display mode when the menu tab is selected (menu is open).
final FloaticaTabDisplayMode selectedDisplayMode;