res/models/floatica_shape library

Classes

CircleShape
A circular shape for a floating action button or navigation bar.
FloaticaShape
An abstract class that represents a shape for a floating action button or navigation bar.
RectangleShape
A rectangular shape for a floating action button or navigation bar.
SquircleShape
A squircle (superellipse) shape for a floating action button or navigation bar.