FloaticaIndicatorStyle enum

Defines the style of the selection indicator.

Inheritance
Available extensions

Values

background → const FloaticaIndicatorStyle

Background color fills the entire tab (default behavior).

dot → const FloaticaIndicatorStyle

A dot indicator appears below/beside the icon.

underline → const FloaticaIndicatorStyle

An underline appears below the tab content.

none → const FloaticaIndicatorStyle

No indicator, only icon/text color changes.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FloaticaIndicatorStyle>
A constant List of the values in this enum, in order of their declaration.