animationDuration property
Custom animation duration for this tab.
If not provided, uses the default medium duration (400ms).
Implementation
final Duration? animationDuration;
Custom animation duration for this tab.
If not provided, uses the default medium duration (400ms).
final Duration? animationDuration;