badge property
A badge widget to display on top of the icon.
Typically used for notification indicators (dots, numbers, etc.).
Implementation
final Widget? badge;
A badge widget to display on top of the icon.
Typically used for notification indicators (dots, numbers, etc.).
final Widget? badge;