floatyActionButton property
An optional floating action button associated with the tab.
Implementation
final FloaticaActionButton? floatyActionButton;
An optional floating action button associated with the tab.
final FloaticaActionButton? floatyActionButton;