unselectedDisplayMode property
The display mode when the tab is not selected.
Determines what is shown when the tab is not selected (icon only, title only, or both). Defaults to FloaticaTabDisplayMode.iconOnly.
Implementation
final FloaticaTabDisplayMode unselectedDisplayMode;