width property

double? width
final

Optional fixed width for the tab.

If provided, the tab will have a fixed width and the content will be wrapped in a FittedBox to prevent overflow. If not provided, the tab will size to fit its content.

Implementation

final double? width;