FloaticaTabDisplayMode enum
Defines what content is displayed in a tab.
This enum allows customization of what appears in each tab state:
- iconOnly: Only the icon is shown.
- titleOnly: Only the title is shown.
- iconAndTitle: Both icon and title are shown.
Values
- iconOnly → const FloaticaTabDisplayMode
-
Only the icon is displayed.
- titleOnly → const FloaticaTabDisplayMode
-
Only the title is displayed.
- iconAndTitle → const FloaticaTabDisplayMode
-
Both icon and title are displayed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FloaticaTabDisplayMode> - A constant List of the values in this enum, in order of their declaration.