FloatyNavBar constructor
const
FloatyNavBar({
- Key? key,
- required List<
FloaticaTab> tabs, - required int selectedTab,
- EdgeInsetsGeometry? margin = const EdgeInsetsDirectional.symmetric(vertical: 16),
- double height = 60,
- double gap = 16,
- Color? backgroundColor,
- List<
BoxShadow> ? boxShadow, - BorderRadius borderRadius = const BorderRadius.all(Radius.circular(100)),
- FloaticaGlassEffect? glassEffect,
Creates a FloatyNavBar.
The tabs parameter is required and provides the list of tabs to display in
the navigation bar. The selectedTab parameter specifies the index of the
currently selected tab.
The following parameters are optional:
margin: The margin around the navigation bar.height: The height of the navigation bar. Defaults to 60.gap: The gap between the tab bar and the action button. Defaults to 16.backgroundColor: The background color of the navigation bar.boxShadow: The shadow effect applied to the navigation bar.borderRadius: The border radius of the navigation bar.
Implementation
const FloatyNavBar({
super.key,
required this.tabs,
required this.selectedTab,
this.margin = const EdgeInsetsDirectional.symmetric(vertical: 16),
this.height = 60,
this.gap = 16,
this.backgroundColor,
this.boxShadow,
this.borderRadius = const BorderRadius.all(Radius.circular(100)),
this.glassEffect,
this.menu,
});