innerShadow property

bool innerShadow
final

Whether to enable an inner shadow for added depth.

Adds dark gradients around the inner edges (top, bottom, sides) to create a sense of glass thickness and depth.

Implementation

final bool innerShadow;