CircleShape class
A circular shape for a floating action button or navigation bar.
This shape creates a circular button with a customizable border radius. The default radius is 100, making it suitable for pill-shaped designs.
- Inheritance
-
- Object
- FloaticaShape
- CircleShape
Constructors
- CircleShape({double radius = 100})
-
const
Properties
- borderRadius → BorderRadius
-
The BorderRadius for this shape.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- radius → double
-
The radius used to round the corners.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeBorder → ShapeBorder
-
A ShapeBorder that represents the specific shape.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited